@@ -23,7 +23,7 @@
  * in the United States and other countries.]
  *
  * ------------
- * $Id: ContentNormalizer.java,v 1.17 2007/04/02 11:41:16 taqua Exp $
+ * $Id: ContentNormalizer.java 3524 2007-10-16 11:26:31Z tmorgner $
  * ------------
  * (C) Copyright 2006-2007, by Pentaho Corporation.
  */
@@ -129,7 +129,7 @@ public class ContentNormalizer implements Normalizer
     private long nextId;
     private State recordingContentNormalizerState;
 
-    public ContentNormalizerState()
+    protected ContentNormalizerState()
     {
     }
 
@@ -193,10 +193,10 @@ public class ContentNormalizer implements Normalizer
      * @return the saved state
      * @throws StateException
      */
-    public StatefullComponent restore(LayoutProcess layoutProcess)
+    public StatefullComponent restore(final LayoutProcess layoutProcess)
         throws StateException
     {
-      ContentNormalizer contentNormalizer =
+      final ContentNormalizer contentNormalizer =
           new ContentNormalizer(layoutProcess, false);
       contentNormalizer.restore(this);
       return contentNormalizer;
@@ -279,9 +279,9 @@ public class ContentNormalizer implements Normalizer
    * @throws NormalizationException
    * @throws IOException
    */
-  public void startElement(String namespace,
-                           String tag,
-                           AttributeMap attributes)
+  public void startElement(final String namespace,
+                           final String tag,
+                           final AttributeMap attributes)
       throws NormalizationException, IOException
   {
     // the contents of what is stored here is rather uninteresting,
@@ -297,10 +297,10 @@ public class ContentNormalizer implements Normalizer
     startElementInternal(namespace, tag, null, attributes);
   }
 
-  protected void startElementInternal(String namespace,
-                                      String tag,
-                                      String pseudo,
-                                      AttributeMap attributes)
+  protected void startElementInternal(final String namespace,
+                                      final String tag,
+                                      final String pseudo,
+                                      final AttributeMap attributes)
       throws NormalizationException, IOException
   {
 
@@ -429,7 +429,7 @@ public class ContentNormalizer implements Normalizer
     }
   }
 
-  protected boolean generateBeforePseudoElements(LayoutElement element)
+  protected boolean generateBeforePseudoElements(final LayoutElement element)
       throws IOException, NormalizationException
   {
     final LayoutContext layoutContext = element.getLayoutContext();
@@ -504,14 +504,14 @@ public class ContentNormalizer implements Normalizer
     if (MoveToValues.HERE.equals(value) == false)
     {
       // Some moved content.
-      String target;
+      final String target;
       if (value == null)
       {
         target = null;
       }
       else if (value instanceof CSSStringValue)
       {
-        CSSStringValue sval = (CSSStringValue) value;
+        final CSSStringValue sval = (CSSStringValue) value;
         target = sval.getValue();
       }
       else
@@ -580,7 +580,7 @@ public class ContentNormalizer implements Normalizer
       }
       for (int i = 0; i < list.getLength(); i++)
       {
-        CSSValue val = list.getItem(i);
+        final CSSValue val = list.getItem(i);
         if (val instanceof ContentsToken)
         {
           return true;
@@ -590,7 +590,7 @@ public class ContentNormalizer implements Normalizer
     return false;
   }
 
-  protected boolean generateContentBefore(LayoutElement element)
+  protected boolean generateContentBefore(final LayoutElement element)
       throws IOException, NormalizationException
   {
     final ContentSpecification cspec =
@@ -620,7 +620,7 @@ public class ContentNormalizer implements Normalizer
     return false;
   }
 
-  protected void generateContentAfter(LayoutElement element)
+  protected void generateContentAfter(final LayoutElement element)
       throws IOException, NormalizationException
   {
     final ContentSpecification cspec =
@@ -662,7 +662,7 @@ public class ContentNormalizer implements Normalizer
   }
 
 
-  protected void generateStrings(LayoutElement element)
+  protected void generateStrings(final LayoutElement element)
       throws IOException, NormalizationException
   {
     final ContentSpecification cspec =
@@ -700,7 +700,7 @@ public class ContentNormalizer implements Normalizer
   }
 
 
-  protected void generateAfterPseudoElements(LayoutElement element)
+  protected void generateAfterPseudoElements(final LayoutElement element)
       throws IOException, NormalizationException
   {
     final LayoutContext layoutContext = element.getLayoutContext();
@@ -723,7 +723,7 @@ public class ContentNormalizer implements Normalizer
    * @throws NormalizationException
    * @throws IOException
    */
-  public void addText(String text) throws NormalizationException, IOException
+  public void addText(final String text) throws NormalizationException, IOException
   {
     if (ignoreContext > 0)
     {
@@ -757,7 +757,7 @@ public class ContentNormalizer implements Normalizer
   {
     if (token instanceof CloseQuoteToken)
     {
-      CloseQuoteToken closeQuoteToken = (CloseQuoteToken) token;
+      final CloseQuoteToken closeQuoteToken = (CloseQuoteToken) token;
       if (closeQuoteToken.isSurpressQuoteText())
       {
         quoteLevel -= 1;
@@ -775,7 +775,7 @@ public class ContentNormalizer implements Normalizer
     }
     else if (token instanceof OpenQuoteToken)
     {
-      OpenQuoteToken openQuoteToken = (OpenQuoteToken) token;
+      final OpenQuoteToken openQuoteToken = (OpenQuoteToken) token;
       if (openQuoteToken.isSurpressQuoteText())
       {
         quoteLevel += 1;
@@ -810,7 +810,7 @@ public class ContentNormalizer implements Normalizer
     {
       final CountersToken counterToken = (CountersToken) token;
       final String name = counterToken.getName();
-      IntList counterValues = new IntList(10);
+      final IntList counterValues = new IntList(10);
       while (currentElement != null)
       {
         if (currentElement.isCounterDefined(name))
@@ -836,7 +836,7 @@ public class ContentNormalizer implements Normalizer
   {
     final ContentSpecification cspec =
         currentElement.getLayoutContext().getContentSpecification();
-    QuotesPair[] qps = cspec.getQuotes();
+    final QuotesPair[] qps = cspec.getQuotes();
     final int maxQuote = Math.min(qps.length - 1, quoteLevel);
     if (maxQuote == -1)
     {
@@ -882,7 +882,7 @@ public class ContentNormalizer implements Normalizer
     if (ignoreContext == 1)
     {
       // check, what caused the trouble ..
-      LayoutContext layoutContext = currentElement.getLayoutContext();
+      final LayoutContext layoutContext = currentElement.getLayoutContext();
       final CSSValue displayRole = layoutContext.getValue(BoxStyleKeys.DISPLAY_ROLE);
       if (DisplayRole.NONE.equals(displayRole))
       {
@@ -902,7 +902,7 @@ public class ContentNormalizer implements Normalizer
 
     if (ignoreContext == 1)
     {
-      LayoutContext layoutContext = currentElement.getLayoutContext();
+      final LayoutContext layoutContext = currentElement.getLayoutContext();
       final ContentSpecification contentSpec =
           layoutContext.getContentSpecification();
 
@@ -998,7 +998,7 @@ public class ContentNormalizer implements Normalizer
     return new ContentNormalizerState();
   }
 
-  protected void fillState(ContentNormalizerState state) throws StateException
+  protected void fillState(final ContentNormalizerState state) throws StateException
   {
     state.setNextId(nextId);
     state.setCurrentElement(currentElement);
@@ -1013,7 +1013,7 @@ public class ContentNormalizer implements Normalizer
 
   public State saveState() throws StateException
   {
-    ContentNormalizerState state = createSaveState();
+    final ContentNormalizerState state = createSaveState();
     fillState(state);
     return state;
   }
